==> wow-test-1.9.2-sources.jar: me/ahoo/wow/test/aggregate/GivenInitializationCommand.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.test.aggregate

import me.ahoo.wow.api.command.CommandMessage
import me.ahoo.wow.api.messaging.Header
import me.ahoo.wow.api.modeling.AggregateId
import me.ahoo.wow.api.modeling.NamedAggregate
import me.ahoo.wow.id.GlobalIdGenerator
import me.ahoo.wow.messaging.DefaultHeader

object GivenInitialization

data class GivenInitializationCommand(
    override val aggregateId: AggregateId,
    override val id: String = GlobalIdGenerator.generateAsString(),
    override val requestId: String = GlobalIdGenerator.generateAsString(),
    override val isCreate: Boolean = true,
    override val allowCreate: Boolean = false,
) : CommandMessage<GivenInitialization>, NamedAggregate by aggregateId {
    override val body: GivenInitialization = GivenInitialization
    override val aggregateVersion: Int? = null
    override val name: String = GivenInitializationCommand::javaClass.name
    override val header: Header = DefaultHeader.EMPTY
    override val createTime: Long = System.currentTimeMillis()

    override fun mergeHeader(additionalSource: Map<String, String>): CommandMessage<GivenInitialization> {
        return this
    }
}

==> wow-test-1.13.5-sources.jar: me/ahoo/wow/test/aggregate/GivenInitializationCommand.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.test.aggregate

import me.ahoo.wow.api.command.CommandMessage
import me.ahoo.wow.api.messaging.Header
import me.ahoo.wow.api.modeling.AggregateId
import me.ahoo.wow.api.modeling.NamedAggregate
import me.ahoo.wow.id.GlobalIdGenerator
import me.ahoo.wow.messaging.DefaultHeader

object GivenInitialization

data class GivenInitializationCommand(
    override val aggregateId: AggregateId,
    override val id: String = GlobalIdGenerator.generateAsString(),
    override val requestId: String = GlobalIdGenerator.generateAsString(),
    override val isCreate: Boolean = true,
    override val allowCreate: Boolean = false
) : CommandMessage<GivenInitialization>, NamedAggregate by aggregateId {
    override val body: GivenInitialization = GivenInitialization
    override val aggregateVersion: Int? = null
    override val name: String = GivenInitializationCommand::javaClass.name
    override val header: Header = DefaultHeader.EMPTY
    override val createTime: Long = System.currentTimeMillis()

    override fun mergeHeader(additionalSource: Map<String, String>): CommandMessage<GivenInitialization> {
        return this
    }
}
